@@ -15,9 +15,9 @@ except ImportError:
 libraries = ['SDL2', 'SDL2_mixer', 'SDL2_ttf', 'SDL2_image', 'SDL2_gfx']
 
 libversions = {
-    'SDL2': '2.0.16',
+    'SDL2': '2.0.20',
     'SDL2_mixer': '2.0.4',
-    'SDL2_ttf': '2.0.15',
+    'SDL2_ttf': '2.0.18',
     'SDL2_image': '2.0.5',
     'SDL2_gfx': '1.0.4'
 }
@@ -182,6 +182,7 @@ def getDLLs(platform_name):
 def buildDLLs(libraries, basedir, libdir):
 
         suffix = '.tar.gz' # source code
+        arch = os.uname()[-1]
 
         # Set required environment variables for custom prefix
         buildenv = os.environ.copy()
@@ -193,6 +194,13 @@ def buildDLLs(libraries, basedir, libdir):
         buildenv['LDFLAGS'] = "-L" + os.path.abspath(builtlib_dir)
         buildenv['CPPFLAGS'] = '-I{0}'.format(os.path.abspath(include_dir))
 
+        # Fetch updated config.guess/config.sub scripts (needed for gfx on non-x86)
+        cfgfiles = {}
+        cfgnames = ['config.guess', 'config.sub']
+        cfgurl = 'https://git.savannah.gnu.org/cgit/config.git/plain/{0}'
+        for name in cfgnames:
+            cfgfiles[name] = urlopen(cfgurl.format(name)).read()
+
         for lib in libraries:
 
             libversion = libversions[lib]
@@ -207,8 +215,10 @@ def buildDLLs(libraries, basedir, libdir):
             dependencies = []
             ignore = [
                 'libvorbisidec', # only needed for special non-standard builds
-            ] 
-            build_first = ['zlib', 'harfbuzz']
+                'freetype', # built by default in current TTF release
+                'harfbuzz', # built by default in current TTF release
+            ]
+            build_first = ['zlib']
             build_last = ['libvorbis', 'opusfile', 'flac']
             ext_dir = os.path.join(sourcepath, 'external')
             if os.path.exists(ext_dir):
@@ -232,7 +242,6 @@ def buildDLLs(libraries, basedir, libdir):
             # Build any external dependencies
             extra_args = {
                 'opusfile': ['--disable-http'],
-                'freetype': ['--enable-freetype-config']
             }
             for dep in dependencies:
                 depname, depversion = dep.split('-')
@@ -246,7 +255,7 @@ def buildDLLs(libraries, basedir, libdir):
                 xtra_args = None
                 if depname in extra_args.keys():
                     xtra_args = extra_args[depname]
-                success = make_install_lib(dep_path, libdir, buildenv, xtra_args)
+                success = make_install_lib(dep_path, libdir, buildenv, xtra_args, cfgfiles)
                 if not success:
                     raise RuntimeError("Error building {0}".format(dep))
                 print('\n======= {0} built sucessfully =======\n'.format(dep))
@@ -254,9 +263,9 @@ def buildDLLs(libraries, basedir, libdir):
             # Build the library
             print('======= Compiling {0} {1} =======\n'.format(lib, libversion))
             xtra_args = None
-            if lib == 'SDL2_ttf':
-                xtra_args = ['--with-ft-prefix={0}'.format(os.path.abspath(libdir))]
-            success = make_install_lib(sourcepath, libdir, buildenv, xtra_args)
+            if lib == 'SDL2_gfx' and not arch in ['i386', 'x86_64']:
+                xtra_args = ['--disable-mmx']
+            success = make_install_lib(sourcepath, libdir, buildenv, xtra_args, cfgfiles)
             if not success:
                 raise RuntimeError("Error building {0}".format(lib))
             print('\n======= {0} {1} built sucessfully =======\n'.format(lib, libversion))
@@ -301,13 +310,20 @@ def fetch_source(libfolder, liburl, outdir):
     return os.path.join(outdir, libfolder)
 
 
-def make_install_lib(src_path, prefix, buildenv, extra_args=None):
+def make_install_lib(src_path, prefix, buildenv, extra_args=None, config={}):
     """Builds and installs a library into a given prefix using GNU Make.
     """
     orig_path = os.getcwd()
     os.chdir(src_path)
     success = True
 
+    # If updated config.guess/config.sub files provided, use those
+    for name in config.keys():
+        subdir_path = os.path.join('config', name)
+        filepath = subdir_path if os.path.isfile(subdir_path) else name
+        with open(filepath, 'wb') as out:
+            out.write(config[name])
+
     buildcmds = [
         ['./configure', '--prefix={0}'.format(prefix)],
         ['make', '-j2'],
